package com.dsk.cscec.controller;


import com.dsk.common.core.controller.BaseController;
import com.dsk.common.core.domain.PageQuery;
import com.dsk.common.core.domain.R;
import com.dsk.common.core.page.TableDataInfo;
import com.dsk.cscec.domain.AdvisoryBodyCustomForm;
import com.dsk.cscec.domain.bo.*;
import com.dsk.cscec.domain.vo.*;
import com.dsk.cscec.service.AdvisoryBodyCustomFormService;
import com.dsk.cscec.service.AdvisoryBodyProjectService;
import com.dsk.cscec.service.AdvisoryBodyService;
import com.dsk.cscec.service.IDProjectService;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;

/**
 * 咨询机构管理控制层
 *
 * @author sxk
 * @since 2023-12-10 15:34:46
 */
@RestController
@RequestMapping("advisory/body")
public class AdvisoryBodyManageController extends BaseController {
    @Resource
    private IDProjectService baseService;
    @Resource
    private AdvisoryBodyService advisoryBodyService;
    @Resource
    private AdvisoryBodyProjectService advisoryBodyProjectService;
    @Resource
    private AdvisoryBodyCustomFormService advisoryBodyCustomFormService;

    /**
     * 获取所有项目列表数据
     */
    @GetMapping("/getProjectList")
    public TableDataInfo<ProjectSearchVo> getProjectList(ProjectSearchBo projectSearchBo, PageQuery pageQuery) {
        return baseService.queryProjectList(projectSearchBo, pageQuery);
    }

    /**
     * 获取所有企业列表(咨询机构)数据
     */
    @GetMapping("/getAdvisoryBodyList")
    public TableDataInfo<AdvisoryBodySearchVo> getAdvisoryBodyList(AdvisoryBodySearchBo advisoryBodySearchBo, PageQuery pageQuery) {
        return advisoryBodyService.queryAdvisoryBodyList(advisoryBodySearchBo, pageQuery);
    }

    /**
     * 获取合作项目明细
     */
    @GetMapping("/getCooperateProjectDetailList")
    public TableDataInfo<CooperateProjectDetailSearchVo> getCooperateProjectDetailList(@Validated CooperateProjectDetailSearchBo cooperateProjectDetailSearchBo, PageQuery pageQuery) {
        return baseService.queryCooperateProjectDetailList(cooperateProjectDetailSearchBo, pageQuery);
    }

    /**
     * 获取项目详情
     */
    @GetMapping("/getProjectDetail")
    public R<ProjectDetailVo> getProjectDetail(@Validated ProjectDetailBo projectDetailBo) {
        return R.ok(baseService.queryProjectDetail(projectDetailBo));
    }

    /**
     * 校验咨询机构是否存在
     */
    @GetMapping("/checkAdvisoryBodyExist")
    public R<AdvisoryBodyExistVo> checkAdvisoryBodyExist(@NotBlank(message = "咨询机构名称不能为空") String advisoryBodyName) {
        return R.ok(advisoryBodyService.checkAdvisoryBodyExist(advisoryBodyName));
    }

    //todo:咨询机构合作明细,项目承接类型下拉列表接口

    /**
     * 编辑咨询机构结算信息
     * 包含:
     * 新增咨询机构(advisory_body表)
     * 新增/更新咨询机构与项目关联信息(advisory_body_project表)
     */
    @PostMapping("/editAdvisoryBody")
    public R<Void> editAdvisoryBody(@Validated EditAdvisoryBodyInfoBo editInfoBo) {
        System.out.println("👉🏻editInfoBo:"+editInfoBo);
        return toAjax(advisoryBodyService.editAdvisoryBody(editInfoBo));
    }

    /**
     * 获取咨询机构自定义表单
     */
    @GetMapping("/getAdvisoryBodyCustomForm/{projectKey}")
    public R<AdvisoryBodyCustomForm> getAdvisoryBodyCustomForm(@Validated @NotNull(message = "项目主键不能为空") @PathVariable Long projectKey) {
        return R.ok(advisoryBodyCustomFormService.getById(projectKey));
    }

    //todo:自定义表单表格只存一条json数据改造
    /**
     * 新增咨询机构自定义表单
     */
    @PostMapping("/addAdvisoryBodyCustomForm")
    @Transactional(rollbackFor = Exception.class)
    public R<Void> addAdvisoryBodyCustomForm(@Validated AdvisoryBodyCustomForm advisoryBodyCustomForm) {
        return toAjax(advisoryBodyCustomFormService.save(advisoryBodyCustomForm));
    }

    /**
     * 更新咨询机构自定义表单
     */
    @PutMapping("/updateAdvisoryBodyCustomForm")
    @Transactional(rollbackFor = Exception.class)
    public R<Void> updateAdvisoryBodyCustomForm(@Validated AdvisoryBodyCustomForm advisoryBodyCustomForm) {
        return toAjax(advisoryBodyCustomFormService.updateById(advisoryBodyCustomForm));
    }
}